@@ -17,40 +17,40 @@ def get_feature_sleep(tdf, sampling):
     result_axes = feature_set.compute_extra_features(X_axes, sampling)
     return result_axes
 
-# def get_df_from_baf(file):
-#     # step_log.write(get_log_msg("BAF_TO_DF", str(file) + "\n"))
-#     col = ["HEADER_TIME_STAMP", "X_ACCELERATION_METERS_PER_SECOND_SQUARED",
-#            "Y_ACCELERATION_METERS_PER_SECOND_SQUARED", "Z_ACCELERATION_METERS_PER_SECOND_SQUARED"]
-#     tz = os.path.basename(file).split('.')[2].split('-')[-1]
-#
-#     hourdiff = int(tz[1:3])
-#     minutediff = int(tz[3:])
-#
-#     if tz[0] == 'M':
-#         hourdiff = -int(tz[1:3])
-#         minutediff = -int(tz[3:])
-#
-#     in_file = open(file, "rb")
-#     b = in_file.read(20)
-#     diction = {}
-#     i = 0
-#     while len(b) >= 20:
-#         t = int.from_bytes(b[0:8], byteorder='big')
-#         x = struct.unpack('>f', b[8:12])[0]
-#         y = struct.unpack('>f', b[12:16])[0]
-#         z = struct.unpack('>f', b[16:20])[0]
-#         diction[i] = {'time': t, 'x': x, 'y': y, 'z': z}
-#         i = i + 1
-#         b = in_file.read(20)
-#
-#     df = pd.DataFrame.from_dict(diction, "index")
-#     df.columns = col
-#     df['HEADER_TIME_STAMP'] = pd.to_datetime(df['HEADER_TIME_STAMP'], unit='ms') + \
-#                               datetime.timedelta(hours=hourdiff) + datetime.timedelta(minutes=minutediff)
-#     df['X_ACCELERATION_METERS_PER_SECOND_SQUARED'] = df['X_ACCELERATION_METERS_PER_SECOND_SQUARED'] / G_VAL
-#     df['Y_ACCELERATION_METERS_PER_SECOND_SQUARED'] = df['Y_ACCELERATION_METERS_PER_SECOND_SQUARED'] / G_VAL
-#     df['Z_ACCELERATION_METERS_PER_SECOND_SQUARED'] = df['Z_ACCELERATION_METERS_PER_SECOND_SQUARED'] / G_VAL
-#     return df
+def get_df_from_baf(file):
+    # step_log.write(get_log_msg("BAF_TO_DF", str(file) + "\n"))
+    col = ["HEADER_TIME_STAMP", "X_ACCELERATION_METERS_PER_SECOND_SQUARED",
+           "Y_ACCELERATION_METERS_PER_SECOND_SQUARED", "Z_ACCELERATION_METERS_PER_SECOND_SQUARED"]
+    tz = os.path.basename(file).split('.')[2].split('-')[-1]
+
+    hourdiff = int(tz[1:3])
+    minutediff = int(tz[3:])
+
+    if tz[0] == 'M':
+        hourdiff = -int(tz[1:3])
+        minutediff = -int(tz[3:])
+
+    in_file = open(file, "rb")
+    b = in_file.read(20)
+    diction = {}
+    i = 0
+    while len(b) >= 20:
+        t = int.from_bytes(b[0:8], byteorder='big')
+        x = struct.unpack('>f', b[8:12])[0]
+        y = struct.unpack('>f', b[12:16])[0]
+        z = struct.unpack('>f', b[16:20])[0]
+        diction[i] = {'time': t, 'x': x, 'y': y, 'z': z}
+        i = i + 1
+        b = in_file.read(20)
+
+    df = pd.DataFrame.from_dict(diction, "index")
+    df.columns = col
+    df['HEADER_TIME_STAMP'] = pd.to_datetime(df['HEADER_TIME_STAMP'], unit='ms') + \
+                              datetime.timedelta(hours=hourdiff) + datetime.timedelta(minutes=minutediff)
+    df['X_ACCELERATION_METERS_PER_SECOND_SQUARED'] = df['X_ACCELERATION_METERS_PER_SECOND_SQUARED'] / G_VAL
+    df['Y_ACCELERATION_METERS_PER_SECOND_SQUARED'] = df['Y_ACCELERATION_METERS_PER_SECOND_SQUARED'] / G_VAL
+    df['Z_ACCELERATION_METERS_PER_SECOND_SQUARED'] = df['Z_ACCELERATION_METERS_PER_SECOND_SQUARED'] / G_VAL
+    return df
 
 def main(df=None, file_path=None,sampling_rate=None):
 
@@ -112,10 +112,8 @@ def main(df=None, file_path=None,sampling_rate=None):
 
 
 # if __name__ == "__main__":
-#     inPath = 'C:/Users\BINOD\Documents/tmp\missing_watch_data_binod\data-watch/' \
-#              '2020-07-24/13-EDT\AndroidWearWatch-AccelerationCalibrated-NA.020000000000-AccelerationCalibrated.2020-07-24-13-19-58-165-M0400.sensor.baf'
+#     inPath = 'C:/Users\BINOD\Downloads\AndroidPhone-AccelerationCalibrated-NA.020000000000-AccelerationCalibrated.2020-12-27-05-20-20-544-M0800.sensor.baf'
 #     idf = get_df_from_baf(inPath)
-#     fPath = 'C:/Users\BINOD\Documents/tmp\missing_watch_data_binod\data-watch/' \
-#              '2020-07-24/13-EDT/tmp.csv'
+#     fPath = 'C:/Users\BINOD\Downloads\AndroidPhone-FEATURE.csv'
 #     samp_rate = 50
 #     main(idf,fPath,samp_rate)
