@@ -654,7 +654,7 @@ def main(day_folder=None, debug='No'):
     dateSt = tmp_tup[1]
 
     if debug == 'Yes':
-        path = os.path.join(day_folder,'SWaN_' + dateSt + '_debug.csv')
+        path = os.path.join(day_folder,'SWaN_' + dateSt + '_debug_afterOri0to180.csv')
     else:
         path = os.path.join(day_folder,'SWaN_' + dateSt + '_final.csv')
 
